precision\_modulated\_supervised\_autodiff\_pc module
=====================================================

.. automodule:: precision_modulated_supervised_autodiff_pc
   :members:
   :undoc-members:
   :show-inheritance:
